summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authordana <dana@dana.is>2019-04-06 06:59:36 -0500
committerAndrew Gallant <jamslam@gmail.com>2019-04-06 07:59:36 -0400
commitdf4400209afd7703baa6fa5524468f8459eb48bf (patch)
tree67b0144e25618ae8083dc16250628ad161a6f16f
parent77439f99a4535e3b7ba997e5c825dd885a96b725 (diff)
ripgrep: remove extra new-line after Clap output
PR #1222
-rw-r--r--src/args.rs4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/args.rs b/src/args.rs
index c9f2405b..6d9549ed 100644
--- a/src/args.rs
+++ b/src/args.rs
@@ -1654,12 +1654,12 @@ where I: IntoIterator<Item=T>,
if err.use_stderr() {
return Err(err.into());
}
// Explicitly ignore any error returned by writeln!. The most likely error
// at this point is a broken pipe error, in which case, we want to ignore
// it and exit quietly.
//
// (This is the point of this helper function. clap's functionality for
// doing this will panic on a broken pipe error.)
- let _ = writeln!(io::stdout(), "{}", err);
+ let _ = write!(io::stdout(), "{}", err);
process::exit(0);
}
@@ -1654,12 +1654,12 @@ where I: IntoIterator<Item=T>,
return Err(err.into());
}
- // Explicitly ignore any error returned by writeln!. The most likely error
+ // Explicitly ignore any error returned by write!. The most likely error
// at this point is a broken pipe error, in which case, we want to ignore
// it and exit quietly.